pub struct Replacement {
pub value: String,
}Expand description
Represents a single possible replacement of the word.
If you have mispelled a word, the service advises you
to correct the word and all the corrections are suggested
using these Replacement objects.
Fields
value: StringThe suggested word to change to.